@@ -6,11 +6,11 @@ Steemit::WsClient - perl lirary for interacting with the steemit websocket servi
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 
 =head1 SYNOPSIS
@@ -67,8 +67,8 @@ use Mojo::UserAgent;
 use Mojo::JSON qw(decode_json encode_json);
 use Data::Dumper;
 
-has url                => 'https://steemd.steemitstage.com';
-has ua                 =>  sub { Mojo::UserAgent->new };
+has url                => 'https://api.steemit.com/';
+has ua                 => sub { Mojo::UserAgent->new };
 has posting_key        => undef;
 has plain_posting_key  => \&_transform_private_key;
 
@@ -151,7 +151,7 @@ L<https://github.com/steemit/steem/blob/master/libraries/app/database_api.cpp>
 
 sub _request {
    my( $self, $api, $method, @params ) = @_;
-   my $response = $self->ua->get( $self->url, json => {
+   my $response = $self->ua->post( $self->url, json => {
       jsonrpc => '2.0',
       method  => 'call',
       params  => [$api,$method,[@params]],
